==> zither-1.1.15.tar.gz: zither_prj/zither/conf_set.c <==


#include<stdio.h>
#include<unistd.h>
#include<netinet/in.h>
#include<string.h>
#include<stdlib.h>
#include<pthread.h>


#include"zither.h"
#include<almemsys/almemsys.h>


extern global_data_t gd;




int conf_set( char *conf_filename )
{
FILE * FP;
int inA=1;
int stat = 0;
char * tmp;

char * chA = (char *)calloc(IP_LEN, sizeof(char));
char * chB = (char *)calloc(IP_LEN, sizeof(char));
char * chC = (char *)calloc(IP_LEN, sizeof(char));


if((FP = fopen(conf_filename, "r"))!=NULL){
    while(1){
      chA = safe_fpcat(FP, chA, &stat, BUF_MAX);
      if(stat == -1){
         fprintf(stderr,"conf_set(): Terminal of file.\n"); 
         break;
         }
      else {
         if( NULL != strchr(chA,':') && 3 <= mem_count(chA,':') 
             && 5 <= strlen(chA) && 1 != mem_count(chA, '#')){ 
            chB = safe_memcpy(chB, strtok_r(chA, ":", &tmp), BUF_MAX);
            chC = safe_memcpy(chC, strtok_r(NULL, ":", &tmp), BUF_MAX);
	    if(BUF_LEN > strlen(chC) && IP_LEN > strlen(chB)){
               rm_crlf(chC, strlen(chC));
               inA = path_check(chB);
               switch(inA){
                  case 1 : gd.fp.errlog=safe_memcpy(gd.fp.errlog, chC, LOGPATH_LEN);                break;
                  case 2 : gd.fp.file_conf=safe_memcpy(gd.fp.file_conf, chC, LOGPATH_LEN);          break;
                  case 3 : gd.ms.ip_addr = safe_memcpy(gd.ms.ip_addr, chC, IP_LEN);                 break;
                  case 4 : gd.ms.port = strtol(chC, (char **)NULL, 10);                             break;
                  case 5 : gd.ms.max_count = strtol(chC, (char **)NULL, 10);                        break;
                  case 6 : gd.md.ch_MailFrom = safe_memcpy(gd.md.ch_MailFrom, chC, IP_LEN);         break;
                  case 7 : gd.md.ch_MailRcptTo = safe_memcpy(gd.md.ch_MailRcptTo, chC, IP_LEN);     break;
                  case 8 : gd.md.ch_MailServ = safe_memcpy(gd.md.ch_MailServ, chC, IP_LEN);         break;
                  case 9 : gd.bs.life_int= strtol(chC, (char **)NULL, 10);                          break;
                  case 10 : gd.bs.life_los= strtol(chC, (char **)NULL, 10);                         break;
                  case 11 : gd.md.ch_MailCc = safe_memcpy(gd.md.ch_MailCc, chC, IP_LEN);            break;
                  case 12 : gd.fp.lock_path=safe_memcpy(gd.fp.lock_path, chC, LOGPATH_LEN);         break;
                  case 13 : gd.exid.uid = strtol(chC, (char **)NULL, 10);                           break;
                  case 14 : gd.md.in_mailonoff = strtol(chC, (char **)NULL, 10);                    break;
                  case 15 : gd.fp.clock_path=safe_memcpy(gd.fp.clock_path, chC, LOGPATH_LEN);       break;
                  case 16 : gd.fp.connectlog=safe_memcpy(gd.fp.connectlog, chC, LOGPATH_LEN);       break;
                  case 17 : gd.pg.postgres_data=safe_memcpy(gd.pg.postgres_data, chC, LOGPATH_LEN); break;
                  case 18 : gd.pg.pg_webserver=safe_memcpy(gd.pg.pg_webserver, chC, LOGPATH_LEN);   break;
                  default : break;
                  }
	       }
            }
         }
      } 
   fclose( FP );
   }
else {
   fprintf(stderr,"-- CONF FILE NOT OPEN %s\n",conf_filename);
   fprintf(stderr,"-- zither shutdown.\n");
   exit(1);
   }
setup_check();

free(chA);
free(chB);
free(chC);

return 0;
}

==> zither-1.1.16.tar.gz: zither_prj/zither/conf_set.c <==


#include<stdio.h>
#include<unistd.h>
#include<netinet/in.h>
#include<string.h>
#include<stdlib.h>
#include<pthread.h>


#include"zither.h"
#include<almemsys/almemsys.h>


extern global_data_t gd;




int conf_set( char *conf_filename )
{
FILE * FP;
int inA=1;
int stat = 0;
char * tmp;

char * chA = (char *)calloc(IP_LEN, sizeof(char));
char * chB = (char *)calloc(IP_LEN, sizeof(char));
char * chC = (char *)calloc(IP_LEN, sizeof(char));


if((FP = fopen(conf_filename, "r"))!=NULL){
    while(1){
      chA = safe_fpcat(FP, chA, &stat, BUF_MAX);
      if(stat == -1){
         fprintf(stderr,"conf_set(): Terminal of file.\n"); 
         break;
         }
      else {
         if( NULL != strchr(chA,':') && 3 <= mem_count(chA,':') 
             && 5 <= strlen(chA) && 1 != mem_count(chA, '#')){ 
            chB = safe_memcpy(chB, strtok_r(chA, ":", &tmp), BUF_MAX);
            chC = safe_memcpy(chC, strtok_r(NULL, ":", &tmp), BUF_MAX);
	    if(BUF_LEN > strlen(chC) && IP_LEN > strlen(chB)){
               rm_crlf(chC, strlen(chC));
               inA = path_check(chB);
               switch(inA){
                  case 1 : gd.fp.errlog=safe_memcpy(gd.fp.errlog, chC, LOGPATH_LEN);                break;
                  case 2 : gd.fp.file_conf=safe_memcpy(gd.fp.file_conf, chC, LOGPATH_LEN);          break;
                  case 3 : gd.ms.ip_addr = safe_memcpy(gd.ms.ip_addr, chC, IP_LEN);                 break;
                  case 4 : gd.ms.port = strtol(chC, (char **)NULL, 10);                             break;
                  case 5 : gd.ms.max_count = strtol(chC, (char **)NULL, 10);                        break;
                  case 6 : gd.md.ch_MailFrom = safe_memcpy(gd.md.ch_MailFrom, chC, IP_LEN);         break;
                  case 7 : gd.md.ch_MailRcptTo = safe_memcpy(gd.md.ch_MailRcptTo, chC, IP_LEN);     break;
                  case 8 : gd.md.ch_MailServ = safe_memcpy(gd.md.ch_MailServ, chC, IP_LEN);         break;
                  case 9 : gd.bs.life_int= strtol(chC, (char **)NULL, 10);                          break;
                  case 10 : gd.bs.life_los= strtol(chC, (char **)NULL, 10);                         break;
                  case 11 : gd.md.ch_MailCc = safe_memcpy(gd.md.ch_MailCc, chC, IP_LEN);            break;
                  case 12 : gd.fp.lock_path=safe_memcpy(gd.fp.lock_path, chC, LOGPATH_LEN);         break;
                  case 13 : gd.exid.uid = strtol(chC, (char **)NULL, 10);                           break;
                  case 14 : gd.md.in_mailonoff = strtol(chC, (char **)NULL, 10);                    break;
                  case 15 : gd.fp.clock_path=safe_memcpy(gd.fp.clock_path, chC, LOGPATH_LEN);       break;
                  case 16 : gd.fp.connectlog=safe_memcpy(gd.fp.connectlog, chC, LOGPATH_LEN);       break;
                  case 17 : gd.pg.postgres_data=safe_memcpy(gd.pg.postgres_data, chC, LOGPATH_LEN); break;
                  case 18 : gd.pg.pg_webserver=safe_memcpy(gd.pg.pg_webserver, chC, LOGPATH_LEN);   break;
                  case 20 : gd.mysql.mysql_server=safe_memcpy(gd.mysql.mysql_server, chC, LOGPATH_LEN); break;
                  case 21 : gd.mysql.mysql_username=safe_memcpy(gd.mysql.mysql_username, chC, LOGPATH_LEN); break;
                  case 22 : gd.mysql.mysql_password=safe_memcpy(gd.mysql.mysql_password, chC, LOGPATH_LEN); break;
                  case 23 : gd.mysql.mysql_db=safe_memcpy(gd.mysql.mysql_db, chC, LOGPATH_LEN); break;
                  case 24 : gd.db_select=safe_memcpy(gd.db_select, chC, LOGPATH_LEN); break;
                  default : break;
                  }
	       }
            }
         }
      } 
   fclose( FP );
   }
else {
   fprintf(stderr,"-- CONF FILE NOT OPEN %s\n",conf_filename);
   fprintf(stderr,"-- zither shutdown.\n");
   exit(1);
   }
setup_check();

free(chA);
free(chB);
free(chC);

return 0;
}
